@@ -3,6 +3,8 @@ from .DensityFlow import DensityFlow
 from .PerturbE import PerturbE
 from .TranscriptomeDecoder import TranscriptomeDecoder
 from .SimpleTranscriptomeDecoder import SimpleTranscriptomeDecoder
+from .EfficientTranscriptomeDecoder import EfficientTranscriptomeDecoder 
+from .VirtualCellDecoder import VirtualCellDecoder
 
 from . import utils 
 from . import codebook
@@ -14,5 +16,8 @@ from . import perturb
 from . import PerturbE
 from . import TranscriptomeDecoder
 from . import SimpleTranscriptomeDecoder
+from . import EfficientTranscriptomeDecoder
+from . import VirtualCellDecoder
 
-__all__ = ['SURE', 'DensityFlow', 'PerturbE', 'TranscriptomeDecoder', 'SimpleTranscriptomeDecoder', 'flow', 'perturb', 'atac', 'utils', 'codebook']
\ No newline at end of file
+__all__ = ['SURE', 'DensityFlow', 'PerturbE', 'TranscriptomeDecoder', 'SimpleTranscriptomeDecoder',
+           'EfficientTranscriptomeDecoder', 'VirtualCellDecoder', 'flow', 'perturb', 'atac', 'utils', 'codebook']
\ No newline at end of file
